# Checklist
Checklist for flight safety and metadata logs compatible with oucass-profiles.

Safety checks include
* Check for visual obstacles and potential source of interference
* Clear and agree on a takeoff and landing zone
* Decide if current weather conditions are appropriate for safe flight
* Visual inspection of the vehicle
* Verify Mission Planner software prepared
* Connect ground station RF to laptop
* Verify controller prepared
* UAV battery setup
* Connect telemetry 
* Confirm no error messages with Mission Planner
* Confirm GPS fix type (outdoors must get 3D fix)
* Check data logging
* Place vehicle at launch point
* Check flight mode on controller
* Confirm data logging software running
* Check sensors are in correct range
* Review flight plan - verbal and on Mission Planner
* Test audio communications among participants
* Check if all participants ready for flight
* Arm UAV
* Check GPS lock
* Clear props
* Notify participants mission is complete
* Disarm UAV
* Disconnect battery
* Inspect UAV

Metadata logs include
* Location name and ID
* Location info, such as the surface altitude, nearby Mesonet stations, and region from the CF Standard Region List	
* Pilot in command
* Other pilots on site for COA flights	
* Flight objective
* FAA authorization type	
* Platform (UAV) ID	
* Scoop ID
* Battery ID
* Initial and final battery voltages
* Cloud cover
* Rain (yes/no)
* Maximum planned and maximum obtained altitudes	
* Launch and land times (in UTC)
* Emergency documentation
* Private and public remarks

